@@ -1,9 +1,15 @@
-from sentimeter.sentimeter import EngineObserver
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+import logging
+from sentimeter.engine_observer import EngineObserver
 
 
 class BaseSource(EngineObserver):
     def __init__(self, engine) -> None:
-        """ """
+        """The Source Base class
+        The class can be inherited to implement own run methods
+        When a Source is created, it register with the engine as observer to process the events
+        """
         # register to the app
         engine.add_observer(self)
         self.engine = engine
@@ -14,6 +20,7 @@ class BaseSource(EngineObserver):
         pass
 
     def on_results(self, results):
+        """Unused for now"""
         pass
 
     def on_event(self, results):
@@ -24,6 +31,10 @@ class BaseSource(EngineObserver):
 
 
 class TextSource(BaseSource):
+    """The simplest SentimeterSource
+    The Instance can be created and executed with plain text
+    """
+
     def __init__(self, engine) -> None:
         super().__init__(engine)
         pass
@@ -33,4 +44,5 @@ class TextSource(BaseSource):
         return True
 
     def on_event(self, results):
-        print(results)
+        """Just print it"""
+        logging.info(results)
